package org.openxma.dsl.platform.assembler;

import org.openxma.dsl.platform.service.impl.EntitySupportMapper;

/**
 * Support class for {@link EntitySupportMapper entity mapper}, providing a contract for classes which are able to
 * map/convert objects to some other presentation.
 */
public interface DtoAssembler<D> {
    /**
     * The class of <code>sourceDto</code> must be either of the type returned<br>
     * by the method {@link DtoAssembler.getSupportedDtoClass()} or the superType thereof in case that the superType is
     * another dto class.
     * 
     * @param targetClass
     *            the target class (either a supported entity or dto) to map to
     * @param sourceDto
     *            a dto object to map from.
     * 
     * @return a mapped instance of the given target class
     */
    <T> T mapTo(D sourceDto, Class<T> targetClass);

    /**
     * The class of <code>sourceDto</code> must be either of the type returned<br>
     * by the method {@link DtoAssembler.getSupportedDtoClass()} or the superType thereof in case that the superType is
     * another dto class.
     * 
     * @param targetObject
     *            the target class (either a supported entity or dto) to map to
     * @param sourceDto
     *            a dto object to map from
     */
    void mapTo(D sourceDto, Object targetObject);

    /**
     * @param sourceEntity
     *            an entity interface to map from
     * @return a dto object with values mapped from <code>sourceEntity</code>
     */
    D mapFromEntity(Object sourceEntity);

    /**
     * @param sourceEntity
     *          an entity interface to map from
     * @param targetDto
     *          a dto object to map to
     *          
     * @return <code>targetDto</code> with values mapped from <code>sourceEntity</code>
     */
    D mapFromEntity(Object sourceEntity, D targetDto);

}
