package org.openxma.dsl.platform.converter;

import java.text.DateFormat;

/**
 * interface to be implemented by all openXMA DataType converters
 */
public interface Converter {

    /**
     * @param <T>
     *            the type of the returned {@link Object}
     * @param destClass
     *            the class of the object to be returned and the <code>sourceObject</code> should be converted to.
     * @param sourceObject
     *            the object to be converted
     * @return an {@link Object} of type <code>T</code> which should be a converted representation of the
     *         <code>sourceObject</code>.
     * @throws an
     *             {@link IllegalArgumentException} if the datatype conversion can not be done
     */
    <T> T convert(Class<T> destClass, Object sourceObject);

    void setDefaultDateFormatPattern(String defaultDateFormatPattern);
    
    void resetDefaultDateFormatPattern();

    DateFormat getCachedDateFormat(String pattern);
    
    int getDateFormatPatternCacheSize();
}
