/*******************************************************************************
 * @(#) $Id: SortOrderSpecification.java 4277 2009-11-17 12:25:06Z michael_clay $
 * 
 * Copyright (c) 2003, 2008 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 * 
 * $Created$
 * $Revision: 4277 $
 * Last Change: $Date: 2009-11-17 13:25:06 +0100 (Tue, 17 Nov 2009) $ by $Author: michael_clay $
 *******************************************************************************/
package org.openxma.dsl.platform.dao;

import java.util.Collections;
import java.util.LinkedHashSet;
import java.util.Set;

/**
 * Represents a specification of an order clause implemented with a
 * builder like API to conveniently chain or bind multiple <code>Order</code>
 * definitions under a given name.
 * 
 * @version $Revision: 4277 $ $Date: 2009-11-17 13:25:06 +0100 (Tue, 17 Nov 2009) $
 */
public class SortOrderSpecification {
    private String name;
    private Set<SortOrder> sortOrders = new LinkedHashSet<SortOrder>();

    /**
     * @param name
     */
    protected SortOrderSpecification(String name) {
        this.name = name;
    }
    /**
     * @return the name
     */
    public String getName() {
        return name;
    }
    /**
     * Ascending order
     * 
     * @param propertyName
     * @return Order
     */
    public SortOrderSpecification asc(String propertyName) {
        this.sortOrders.add(new SortOrder(propertyName, true));
        return this;
    }
    /**
     * Descending order
     * 
     * @param propertyName
     * @return Order
     */
    public SortOrderSpecification desc(String propertyName) {
        this.sortOrders.add(new SortOrder(propertyName, false));
        return this;
    }
    /**
     * @return the orders
     */
    public Set<SortOrder> getSortOrders() {
        return Collections.unmodifiableSet(this.sortOrders);
    }
    /**
     * 
     * @param name the name of the order specification
     * @return a new <code>OrderSpecification</code> instance
     */
    public static SortOrderSpecification create(String name) {
        return new SortOrderSpecification(name);
    }
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		return result;
	}
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		SortOrderSpecification other = (SortOrderSpecification) obj;
		if (name == null) {
			if (other.name != null)
				return false;
		} else if (!name.equals(other.name))
			return false;
		return true;
	}
	@Override
	public String toString() {
		return "OrderSpecification [name=" + name + ", orders=" + sortOrders + "]";
	}
}
