/*
 * @(#) $Id:  $
 *
 * Copyright 2009/2010 by sIT Solutions,
 * A-1110 Wien, Geiselbergstr.21-25.
 * All rights reserved.
 *
 */
package org.openxma.dsl.platform.exceptions;

/**
 * An application exception that communicates that the update of an object has failed
 * due to an intermediate update by a concurrent process. Usually concurrent updates
 * are detected through optimistic locking.
 * A bean name is always required when creating a ConcurrentUpdateException.
 * 
 * <p>There is a default error code but a more specific error code can be defined,
 * which will be used as resource bundle key to be resolved to a more specific error message.
 * See {@link MessageProvider} and its implementations for message resolution.
 */
public class ConcurrentUpdateException extends ApplicationException {

    private static final long serialVersionUID = 1L;

    public static final String ERR_CONCUR_UPDATE = "error.concurrent_update";

    private final String beanName;

    public ConcurrentUpdateException(String beanName, String defaultMessage) {
        this(ERR_CONCUR_UPDATE, beanName, defaultMessage);
    }

    public ConcurrentUpdateException(String errorCode, String beanName, String defaultMessage) {
        super(errorCode, new Object[] { beanName }, defaultMessage);
        this.beanName = beanName;
    }

    String getBeanName() {
        return beanName;
    }
}
