/*
 * @(#) $Id:  $
 *
 * Copyright 2009/2010 by sIT Solutions,
 * A-1110 Wien, Geiselbergstr.21-25.
 * All rights reserved.
 *
 */
package org.openxma.dsl.platform.exceptions;

/**
 * An application exception that transports a property validation error.
 * Bean and property names and a default message are always required when
 * creating a PropertyValidationException.<br/>
 * Will usually be contained in a {@link BeanValidationException}
 */
public class PropertyValidationException extends BeanValidationException {

    private static final long serialVersionUID = 1L;

    public static final String ERR_VAL_FIELD = "error.validation.field";

    private final String propertyName;
    private final Object invalidValue;

    public PropertyValidationException(String beanName, String propertyName, Object invalidValue,
            String defaultMessage) {
        this(ERR_VAL_FIELD, beanName, propertyName, invalidValue, defaultMessage);
    }
    
    public PropertyValidationException(String errorCode, String beanName, String propertyName, Object invalidValue,
            String defaultMessage) {
        this(errorCode, beanName, propertyName, invalidValue, new Object [] {propertyName}, defaultMessage);
    }

    public PropertyValidationException(String errorCode, String beanName, String propertyName, Object invalidValue,
            Object[] arguments, String defaultMessage) {
        super(errorCode, beanName, arguments, defaultMessage);
        this.propertyName = propertyName;
        this.invalidValue = invalidValue;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public Object getInvalidValue() {
        return invalidValue;
    }
    
}
