/*
 * @(#) $Id:  $
 *
 * Copyright 2009/2010 by sIT Solutions,
 * A-1110 Wien, Geiselbergstr.21-25.
 * All rights reserved.
 *
 */
package org.openxma.dsl.platform.i18n;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;


public class EntityHelper {
	/**
	 * returns the title for an attribute if the title was defined for <br>
	 * the given attribute. Returns the attributeName if no title was specified. 
	 * 
	 * 
	 * @param modelClass
	 * @param attributeName
	 * @return title for attributeName if the title was defined for <br>
	 * the given attribute. returns the attributeName otherwise.
	 *  
	 * @since 4.1.1
	 * @author s4162
	 */
	public static String getAttributeTitle(Class<?> modelClass, String attributeName) {
		return getAttributeTitle(modelClass, attributeName, Locale.getDefault());
	}
	
	
	/**
	 * returns the title for an attribute if the title was defined for <br>
	 * the given attribute. Returns the attributeName if no title was specified.	 
	 *   
	 * @param modelClass
	 * @param attributeName
	 * @param locale
	 * @param classLoader
	 * @return title for attributeName if the title was defined for <br>
	 * the given attribute. returns the attributeName otherwise.
	 *  
	 * @since 4.1.1
	 * @author s4162
	 */
	public static String getAttributeTitle(Class<?> modelClass, String attributeName, Locale locale, ClassLoader classLoader) {
		String result = attributeName;
		String fqn = getFQNForBundle(modelClass);
		ResourceBundle bundle = null;
		try {
			bundle = getBundle(locale, classLoader, fqn);			
			result = bundle.getString(attributeName +".title");
		} catch (MissingResourceException e) {
			//ignore
		}		
		return result;
		
	}


	private static ResourceBundle getBundle(Locale locale, ClassLoader classLoader, String fqn) {
		return PropertyResourceBundle.getBundle(fqn, locale, classLoader );
	}


	private static String getFQNForBundle(Class<?> modelClass) {
		String fqn = modelClass.getPackage().getName() +"." + modelClass.getSimpleName();
		return fqn;
	}
	/**
	 * 
	 * returns the title for an attribute if the title was defined for <br>
	 * the given attribute. Returns the attributeName if no title was specified. 
	 * 
	 * @param modelClass
	 * @param attributeName
	 * @return title for attributeName if the title was defined for <br>
	 * the given attribute. returns the attributeName otherwise.
	 *  
	 * @since 4.1.1
	 * @author s4162
	 */
	public static String getAttributeTitle(Class<?> modelClass, String attributeName, Locale locale) {
		return getAttributeTitle(modelClass, attributeName, locale, EntityHelper.class.getClassLoader());
	}	

}
